=============
Documentation
=============

.. toctree::
   :maxdepth: 4

Main Module
-----------

.. automodule:: medium_api.medium
   :members:
   :undoc-members:
   :show-inheritance:

Classes
-------

User class
^^^^^^^^^^

.. autoclass:: medium_api._user.User
   :members:

Article class
^^^^^^^^^^^^^

.. autoclass:: medium_api._article.Article
   :members:

Publication class
^^^^^^^^^^^^^^^^^

.. autoclass:: medium_api._publication.Publication
   :members:

LatestPosts class
^^^^^^^^^^^^^^^^^

.. autoclass:: medium_api._latestposts.LatestPosts
   :members:

TopWriters class
^^^^^^^^^^^^^^^^

.. autoclass:: medium_api._top_writers.TopWriters
   :members:

TopFeeds class
^^^^^^^^^^^^^^

.. autoclass:: medium_api._topfeeds.TopFeeds
   :members: